summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJohn Vandenberg <jayvdb@gmail.com>2015-11-03 09:37:47 +1100
committerJohn Vandenberg <jayvdb@gmail.com>2015-11-03 09:37:47 +1100
commit69a715dff7243eda61f0bf5f16b8a37afb5b7ac6 (patch)
treebe8b93cf51b55b2f749cd683900a06c209c63b36
parent2a254e8332aa1d48a40eb2a9d6266de550063815 (diff)
downloadpyflakes-69a715dff7243eda61f0bf5f16b8a37afb5b7ac6.tar.gz
Fix documentation of Binding.used
ef4da24 changed the Binding.used tuple from (scope, line number) to (scope, node). This updates the docstring to reflect this change.
-rw-r--r--pyflakes/checker.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/pyflakes/checker.py b/pyflakes/checker.py
index e6e1942..17e7b66 100644
--- a/pyflakes/checker.py
+++ b/pyflakes/checker.py
@@ -92,8 +92,8 @@ class Binding(object):
which names have not. See L{Assignment} for a special type of binding that
is checked with stricter rules.
- @ivar used: pair of (L{Scope}, line-number) indicating the scope and
- line number that this binding was last used
+ @ivar used: pair of (L{Scope}, node) indicating the scope and
+ the node that this binding was last used.
"""
def __init__(self, name, source):